<?php

namespace EasyVideoReviews;

defined('ABSPATH') or die('Direct Script not Allowed');


/**
 * EVR Ajax Class
 */

if (!class_exists('\EasyVideoReviews\EVR_Ajax')) {
    
    final class EVR_Ajax
    
    {

        /**
         * Class initializing
         */

        static function init()
        {
            $instance = new self;
            $instance->register_hooks();
        }
        
        /**
         * Hooks Register
         */

        function register_hooks()
        {

            add_action('wp_ajax_evr_save_wrat', [$this, 'evr_save_wrat']);
            add_action('wp_ajax_evr_update_subscription', [$this, 'evr_update_subscription']);
            add_action('wp_ajax_evr_logout', [$this, 'evr_logout']);
            add_action('wp_ajax_get_evr_settings', [$this, 'get_evr_settings']);
            add_action('wp_ajax_update_evr_settings', [$this, 'update_evr_settings']);

            add_action('wp_ajax_import_evr_settings', [$this, 'import_evr_settings']);
            add_action('wp_ajax_export_evr_settings', [$this, 'export_evr_settings']);
            add_action('wp_ajax_reset_evr_settings', [$this, 'reset_evr_settings']); 
        } 

        /**
         * Save Auth Token after Login
         */
        function evr_save_wrat()
        {
            update_option('evr_token', sanitize_text_field( $_REQUEST['token'] )); 
            wp_send_json_success();
        }


        function evr_update_subscription()
        {
            update_option('evr_isPro', sanitize_text_field( $_REQUEST['ispro'] )); 
            wp_send_json_success(sanitize_text_field($_REQUEST['ispro']));
        }

        /**
         * Logout and delete auth token
         */
        function evr_logout()
        {

            delete_option('evr_token', true);
            delete_option('evr_isPro', true);
            wp_send_json_success();
        }


        /**
         * Instance of Hooks
         */
        static function app()
        {
            return new \EasyVideoReviews\EVR_App();
        }

        /**
         * Get EVR Plugin Options
         */
        function get_evr_settings()
        {
            $options = self::app()->get_evr_options();

            $output = [];

            foreach ($options as $key => $value) {
                $output[$key] = maybe_unserialize(get_option('evr_' . $key));
            }

            wp_send_json_success($output);
        }

        /**
         * Update EVR Plugin Options
         */
        function update_evr_settings()
        { 

            $options = self::app()->get_evr_options();
            $v = [];
            foreach ($options as $key => $default) {
                $updated_value = sanitize_text_field(stripslashes($_REQUEST[$key])); 
                update_option('evr_' . $key, $updated_value);
            }
            wp_send_json_success();
        }

        /**
         * Import EVR Plugin Options
         */

        function import_evr_settings()
        {

            $options = array_keys(self::app()->get_evr_options());
 
            $inp_options = sanitize_text_field($_REQUEST['settings']);

            foreach ($inp_options as $key => $value) {
                if (in_array($key, $options)) {
                    $updated_value = sanitize_text_field(stripslashes($_REQUEST[$key])); 
                    update_option('evr_' . $key, $updated_value);
                }
            }
            wp_send_json_success();
            wp_die();
        }

        /**
         * Export EVR Plugin Options
         */
        function export_evr_settings()
        {

            $options = array_keys(self::app()->get_evr_options());

            $results = [];
            foreach ($options as $key) {
                $results[$key] = maybe_unserialize(get_option('evr_' . $key));
            }

            if ($results && !empty($results)) wp_send_json_success($results);
            wp_send_json_error();
            wp_die();
        }

        /**
         * Reset EVR Plugin Options
         */
        function reset_evr_settings()
        {
            $hooks = new \EasyVideoReviews\EVR_Hooks();
            $response = $hooks->reset_evr_options(true);
            wp_send_json_success($response);
            wp_die();
        }
 
    }

}
