<?php

namespace EasyVideoReviews;

defined('ABSPATH') or die('Direct Script not Allowed');


/**
 * EVR Ajax Class
 */

if (!class_exists('\EasyVideoReviews\EVR_App')) {
    
    final class EVR_App
    
    {

        /**
         * Secret Member data
         */

        const APPSERO_HASH = '98bea24e-5324-4ccf-932a-6f1c77b67ad6';

        /**
         * 
         * Intance of the plugin
         */

         static public function getInstace(){
             return new self;
         }

        /**
         * Class initializing
         */

        public static function init()
        {
            $instance = new self;
            $instance->register_hooks_and_integrations();
        }


        /**
         * Hooks and Integrations
         */
        public function register_hooks_and_integrations()
        {
            /**
             * Init Appsero
             */
            // if(!class_exists('\EVRAppsero\Client')){
                $this->initAppsero();
            // }
           
        }

        /**
         * 
         * Appsero Integrations
         */
        public function initAppsero()
        {

            /**
             * Appsero client initialization
             */
            $client = new \EVRAppsero\Client(self::APPSERO_HASH, 'Easy Video Reviews', EVR_HANDLER_FILE);



            /**
             * Set text-domain
             */
            $client->set_textdomain('easy-video-reviews');

            /**
             * Activate insights
             */
            $client ->insights() 
                    ->init();

            /**
             * Automatic updater
             */
            $client->updater();
            
        } 

        /**
         * Translations
         */
        public static function getTranslations()
        {
            $texts = [
                'Upload Review',
                'Record Review',
                'You can record up to %s minutes, don\'t worry you will review your video before sending',
                'Hide Options',
                'Show Options',
                'Delay',
                'No Delay',
                'Front',
                'Back',
                'Immediate',
                'Seconds',
                'Choose Camera',
                'Default Camera',
                'Choose Microphone',
                'Default Microphone',
                'Looks Good, Continue',
                'Upload Video',
                'Uploading Video',
                'Record New Video',
                'I\'m allowing to publish this video',
                'Submit',
                'Record',
                'Continue',
                'Record Video',
                'Start Over',
                'Drag your files here or click in this area',
                'You have no camera installed on your device or the device is currently being used by other application'
            ];

            $newArray = [];
            foreach ($texts as $text) {
                $newArray[$text] = $text;
            }

            return apply_filters('evr_translations', $newArray);
        }


        /**
         * Get EVR Registered Options 
         */

        public static function get_evr_options()
        {
            $options = [
                'recorder' => [
                    'limits' => 120,
                    'upload' => 0,
                    'publish_policy' => 0,
                    'show_options' => 0,
                    'form' => 0,
                    'delay' => 3,
                    'auto_approve' => true
                ],
                'recorder_page' => '',
                'email' => [
                    'message' => esc_html__('If you like the product, please leave a video review for us {button}', 'easy-video-reviews'),
                    'button' => [
                        'text' => esc_html__('Leave a video review', 'easy-video-reviews'),
                        'bg' => '#96588a',
                        'color' => '#ffffff',
                        'size' => '16',
                    ],
                    'url' => [
                        'label' => esc_html__('Leave a video review', 'easy-video-reviews')
                    ]
                ],
                'button' => [
                    'text' => esc_html__('Leave a video review', 'easy-video-reviews'),
                    'color' => '#f0f0f0',
                    'bg' => '#000099',
                    'size' => '18',
                    'alignment' => 'center'
                ],
                'woocommerce' => [
                    'order_complete' => [
                        'button' => false,
                        'email' => false,
                    ],
                    'single_product' => [
                        'button' => false,
                        'showcase' => [
                            'show' => false,
                            'limit' => 5
                        ]
                    ],

                ],
                'edd' => [
                    'order_complete' => [
                        'button' => false,
                        'email' => false,
                    ],
                    'single_product' => [
                        'button' => false,
                        'showcase' => [
                            'show' => false,
                            'limit' => 5
                        ]
                    ],

                ],
                'optimization' => [
                    'showcase' =>  [
                        'title' => esc_html__('Video Review', 'easy-video-reviews'),
                        'description' => esc_html(get_bloginfo('description')),
                        'slug' => 'video-review',
                    ],
                    'social' => [
                        'facebook' => ['show' => false, 'id' => ''],
                        'twitter' => ['show' => false, 'username' => ''],
                    ]
                ],
                'forms' => [],
                'translations' => self::getTranslations()
            ];

            return apply_filters('evr_options', $options);
        }
 
        /**
         * Client's IP address to log
         */

        public static function getUserIP()
        {
            $ipaddress = '';
            if (isset($_SERVER['HTTP_CLIENT_IP']))
            $ipaddress = $_SERVER['HTTP_CLIENT_IP'];
            else if (isset($_SERVER['HTTP_X_FORWARDED_FOR']))
            $ipaddress = $_SERVER['HTTP_X_FORWARDED_FOR'];
            else if (isset($_SERVER['HTTP_X_FORWARDED']))
            $ipaddress = $_SERVER['HTTP_X_FORWARDED'];
            else if (isset($_SERVER['HTTP_X_CLUSTER_CLIENT_IP']))
            $ipaddress = $_SERVER['HTTP_X_CLUSTER_CLIENT_IP'];
            else if (isset($_SERVER['HTTP_FORWARDED_FOR']))
            $ipaddress = $_SERVER['HTTP_FORWARDED_FOR'];
            else if (isset($_SERVER['HTTP_FORWARDED']))
            $ipaddress = $_SERVER['HTTP_FORWARDED'];
            else if (isset($_SERVER['REMOTE_ADDR']))
            $ipaddress = $_SERVER['REMOTE_ADDR'];
            else
                $ipaddress = 'UNKNOWN';
            return $ipaddress;
        }


        
    }
       
}
