<?php

namespace EasyVideoReviews;

defined('ABSPATH') or die('Direct Script not Allowed');

/** 
 * EVR Hook Class
 **/

if (!class_exists("\EasyVideoReviews\EVR_Hooks")) {

    final class EVR_Hooks

    {
        /**
         * Class instantiate 
         */

        static function init()
        {
            $instance = new self;
            $instance->register_hooks();
        }


        /**
         * Hooks Register
         */
        function register_hooks()
        {
            /**
             * Activation and Deactivation hooks
             */
            register_activation_hook(EVR_HANDLER_FILE, [$this, 'evr_activated']);
            register_deactivation_hook(EVR_HANDLER_FILE, [$this, 'plugin_deactivated']);


            /**
             * other hooks 
             */
            add_action("admin_menu", [$this, 'register_admin_menu']);
            add_action("admin_enqueue_scripts", [$this, 'register_evr_scripts_admin']);
            add_action("wp_enqueue_scripts", [$this, 'register_evr_scripts_frontend']);
            add_action("wp_footer", [$this, 'evr_add_script_wp_footer']); 
            add_action("init", [$this, 'add_evr_custom_shortcode']);
            add_action("admin_init", [$this, 'activated_evr_safe_redirection']);
            add_action("template_redirect", [$this, 'evr_custom_single_video_page']);

            // custom blocks 
            add_action("elementor/widgets/widgets_registered", [$this, 'add_evr_elementor_widgets'], 99);

            // filters 
            add_filter("woocommerce_product_tabs", [$this, 'evr_woocommerce_product_tabs']);
            // triggers 
            add_action("woocommerce_thankyou", [$this, 'evr_woocommerce_thankyou'], 12);
            add_action("woocommerce_email_footer", [$this, 'evr_woocommerce_email_footer'], 0);
            add_action("edd_payment_receipt_after", [$this, 'evr_edd_add_review_button'], 12);
            add_action("edd_email_footer", [$this, 'evr_edd_email_footer'], 12);
            add_action("edd_after_download_content", [$this, 'evr_edd_after_download_content'], 12);

            add_action("admin_print_styles", [$this, 'add_styles_to_single_video_page']);
            add_action("admin_print_styles", [$this, 'add_styles_to_single_video_page']);
            add_action("admin_print_scripts", [$this, 'add_scripts_to_single_video_page']);

            add_action("plugin_action_links_" . plugin_basename(EVR_HANDLER_FILE), [$this, 'evr_plugin_action_links']);
            add_action("elementor/editor/before_enqueue_scripts", [$this, 'evr_elementor_before_enqueue_scripts']);
        }



        /**
         * After activation of EVR
         */

        function evr_activated()
        {

            /**
             * 
             * Reset EVR Options
             */
            $this->reset_evr_options();

            
           /**
            * Create dynamic page if WooCommerce or EDD found installed
            */

            if( class_exists( '\WooCommerce' ) || class_exists( '\Easy_Digital_Downloads' ) ){
                $this->evr_create_dynamic_page();
            } 
        }

        public function evr_create_dynamic_page()
        {
            // add dynamic page 
            $recorder_page = maybe_serialize(get_option('evr_recorder_page'));
            if (empty($recorder_page)) {
                $post_details = array(
                    'post_title'    => __('Leave Video Review', 'easy-video-reviews'),
                    'post_content'  => '[evr-button]Leave a Review[/evr-button]',
                    'post_status'   => 'publish',
                    'post_author'   => 1,
                    'post_type' => 'page'
                );
                $page_id = wp_insert_post($post_details);
                update_option('evr_recorder_page', $page_id);
            }
        }

        /**
         * Redirection after activation 
         */
        function activated_evr_safe_redirection()
        {
            $redirected = get_option('evr_redirected', false);
            if (!$redirected) {
                update_option('evr_redirected', true);
                wp_redirect(admin_url('admin.php?page=evr-admin#subscription'));
                exit();
            }
        }


        /**
         * Plugin deactivatin hook
         */
        function plugin_deactivated()
        {
            // delete authentication token 
            delete_option('evr_token');
            delete_option('evr_redirected', true);
        }


        /**
         * Enqueuing scripts for backend
         */
        function register_evr_scripts_admin()
        {

            $args_pages = array(
                'sort_order' => 'asc',
                'sort_column' => 'post_title',
                'hierarchical' => 1,
                'post_type' => 'page',
                'post_status' => 'publish',
                'posts_per_page' => -1
            );
            $pages = get_pages($args_pages);
            $allpages = [];
            foreach ($pages as $page) {
                $allpages[] = (object) [
                    'id' => esc_html($page->ID),
                    'title' => !empty($page->post_title) ? esc_html($page->post_title) : 'Untitled Page',
                    'slug' => esc_html($page->post_name),
                ];
            }


            $admin_footer_script = [
                "ajaxurl" => admin_url('admin-ajax.php'),
                "sass" => esc_url(EVR_SASS_BASE_URL),
                "plugin_url" => plugin_dir_url(EVR_HANDLER_FILE),
                "home_url" => home_url(),
                "wrat" => get_option('evr_token'),
                "woocommerce" => (bool) class_exists('\WooCommerce'),
                "edd" => (bool) class_exists('\Easy_Digital_Downloads'),
                "pages" => $allpages
            ];
            wp_register_script('evr_object_scripts', '');
            wp_localize_script('evr_object_scripts', 'evr_object', $admin_footer_script);
            wp_enqueue_script('evr_object_scripts');
 
            wp_enqueue_script('evr-vue', plugin_dir_url(EVR_HANDLER_FILE) . 'public/js/vue.global.prod.js', ['jquery'], microtime(), true);
            wp_enqueue_script('evr-admin', plugin_dir_url(EVR_HANDLER_FILE) . 'public/js/admin.js', ['jquery'], microtime(), true);
            wp_enqueue_style('dashicons');
            wp_enqueue_style('evr-admin', plugin_dir_url(EVR_HANDLER_FILE) . 'public/css/admin.css');
        }

        /**
         * Enqueuing scripts for frontend
         */

        function register_evr_scripts_frontend()
        {

            $recorder =  get_evr_option('recorder');
            $forms = get_evr_option('forms');
            $translations = get_evr_option('translations');

            $frontend_footer_script = [
                "sass" => esc_url(EVR_SASS_BASE_URL),
                "ajaxurl" => esc_url(
                    admin_url('admin-ajax.php')),
                "home_url" => esc_url(home_url()),
                "wrat" => esc_html(get_option('evr_token')),
                "preference" => $recorder,
                "forms" => $forms,
                "translations" => $translations,
                "ip" => \EasyVideoReviews\EVR_App::getUserIP()
            ];
            wp_register_script('evr_options_scripts', '');
            wp_localize_script('evr_options_scripts', 'evr_options', $frontend_footer_script);
            wp_enqueue_script('evr_options_scripts');

            wp_enqueue_script('evr-vue', plugin_dir_url(EVR_HANDLER_FILE) . 'public/js/vue.global.prod.js', ['jquery'], filemtime(plugin_dir_path(EVR_HANDLER_FILE) . 'public/js/vue.global.prod.js'), true);
            wp_enqueue_script('evr-frontend', plugin_dir_url(EVR_HANDLER_FILE) . 'public/js/frontend.js', ['jquery'], filemtime(plugin_dir_path(EVR_HANDLER_FILE) . 'public/js/frontend.js'), true);
            wp_enqueue_style('evr-frontend', plugin_dir_url(EVR_HANDLER_FILE) . 'public/css/frontend.css');
        }

        /**
         * Admin menu page 
         */

        function register_admin_menu()
        {
            global $token; 
            $token = get_option('evr_token');
            

            add_menu_page((!$token ? 'Get Started With ' : '') . __('Easy Video Reviews', 'easy-video-reviews'), __('Easy Video Reviews', 'easy-video-reviews'), 'edit_others_posts', 'evr-admin', function () {

                global $token;
                $page_to_load = "get-started";

                if ($token && !empty($token)) {
                    $page_to_load = "dashboard";
                }

                include_once plugin_dir_path(EVR_HANDLER_FILE) . 'templates/admin/' . $page_to_load . '.php';
            }, plugin_dir_url(EVR_HANDLER_FILE) . 'public/images/icon.png', 99);

 
            $isPro = get_option('evr_isPro');;

            if($isPro != 'true')
                add_submenu_page('evr-admin', __('Easy Video Reviews Pro', 'easy-video-reviews'), __('Upgrade <span class="awaiting-mod">Pro</span>', 'easy-video-reviews'),  'edit_others_posts', 'https://go.wppool.dev/Qsy');
        }

        /**
         * Scripts on Frontend Footer
         */
        function evr_add_script_wp_footer()

        {
            /**
             * load the recorder element 
             */
            include_once plugin_dir_path(EVR_HANDLER_FILE) . 'templates/recorder.php';
        }

 
 

        /**
         * Reset EVR Plugin Options to default
         */
        function reset_evr_options()
        {
            $options = \EasyVideoReviews\EVR_App::get_evr_options();
            foreach ($options as $key => $value) {
                update_option('evr_' . $key, maybe_serialize($value));
            }
        } 
        /**
         * Load Elementor Widget
         */

        function add_evr_elementor_widgets()
        {
            $isPro = true;
            
            if (!$isPro) return false; 

            require_once __DIR__ . '/../elementor/elementor-buttons.php';
            require_once __DIR__ . '/../elementor/elementor-showcase.php';
            \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new \EasyVideoReviews\EVR_ElementorButtons());
            \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new \EasyVideoReviews\EVR_ElementorShowcase());
        }


        /**
         * On WooCommerce Single Product Tabs
         */

        function evr_woocommerce_product_tabs($tabs)
        {
            $woocommerce_option = get_evr_option('woocommerce');
            if ($woocommerce_option->single_product->button || $woocommerce_option->single_product->showcase) {
                $tabs['easy_video_reviews'] = array(
                    'title'     => __('Video Reviews', 'easy-video-reviews'),
                    'priority'     => 50,
                    'callback'     => [$this, 'evr_custom_data_tab_callback']
                );
            }

            return $tabs;
        }


        /**
         * WooCommerce Single Product Tabs Callback Function
         */

        function evr_custom_data_tab_callback()
        {
            global $product;
            $tag = esc_attr("prouct-" . $product->get_id());

            $woocommerce_option = get_evr_option('woocommerce');
            $button = get_evr_option('button');
            echo ('<div class="woocommerce">');
            if ($woocommerce_option->single_product->button) {
                echo wp_kses_post(do_shortcode('[evr-button tag=' . $tag . '][/evr-button]'));
            }
            if ($woocommerce_option->single_product->showcase->show) {
                echo wp_kses_post(do_shortcode('[evr-videos limit=' . esc_attr($woocommerce_option->single_product->showcase->limit) . ' tag=' . $tag . ']'));
            }
            echo '</div>';
        }


        /**
         * On WooCommerce Thank you Page
         */

        function evr_woocommerce_thankyou($order_id)
        {
            $woocommerce_option = get_evr_option('woocommerce');
            if (!$woocommerce_option->order_complete->button) return false; 
            echo wp_kses_post(do_shortcode('[evr-button tag=' . esc_attr('order-' . $order_id) . ']'));
        }

        function evr_edd_after_download_content()
        {
            // do nothing
        }



        /**
         * Custom Shortcodes
         */

        function add_evr_custom_shortcode()
        {
            add_shortcode('evr-button', function ($atts, $content) { {

                    $button = get_evr_option('button');  

                    $atts = shortcode_atts(array(
                        'size' => $button->size,
                        'bg' => $button->bg ? $button->bg : 'blue',
                        'color' => $button->color ? $button->color : 'white',
                        'align' => $button->alignment,
                        'tag' => 'general',
                    ), $atts, 'evr-button');

                    $tag = sanitize_text_field($_REQUEST['tag']);
                    $tag = empty($tag) ? $atts['tag'] : $tag;
                    $content2 = sanitize_text_field($_REQUEST['button']);
                    $content = empty($content2) ? ( !empty($content) ? $content : $button->text ) : $content2;
                    $out = "<div class='my-4 text-{$atts['align']}'><a href='javascript:;' class='evr-recorder-button text-{$atts['size']} ' style='color: {$atts['color']}; background: {$atts['bg']}' data-evr-button='{$tag}'>{$content}</a></div>";
                    return $out;
                }
            });

            add_shortcode('evr-videos', function ($atts, $content = null) { {
                    $atts = shortcode_atts(array(
                        'limit' => 10,
                        'view' => 'grid',
                        'cols' => 2,
                        'tag' => 'general',
                        'id' => '',
                    ), $atts, 'evr-videos');


                    $configs = [
                        'limit' => esc_attr($atts['limit']),
                        'order' => esc_attr($atts['order']),
                        'tag' => esc_attr($atts['tag']),
                    ];

                    $showcase = "";

                    if ($atts['view'] == 'slider') {

                        $showcase = "<div class=\"swiper-container evr-swiper\">
                <div class=\"swiper-wrapper\" data-evr-videos='" . wp_json_encode($configs) . "'\">
                    <div class=\"swiper-slide\">
                        <div class=\"swiper-lazy-preloader\"></div>
                    </div>
                </div>
                <div class=\"swiper-pagination\"></div>
                <div class=\"swiper-button-next w-4 h-4\"></div>
                <div class=\"swiper-button-prev w-4 h-4\"></div>
            </div>";
                    } else {

                        $showcase = "<div class=\"grid grid-cols-1 xs:grid-cols-2  gap-2 md:gap-3 lg:gap-4\" data-evr-videos='" . wp_json_encode($configs) . "'\">
                <div class=\"swiper-lazy-preloader\"></div></div>";
                    }


                    return $showcase;
                }
            });
        }



        /**
         * Single page video page / player
         */

        function evr_custom_single_video_page()
        {
            global $wp_query;
            $optimization = get_evr_option('optimization');

            $query_page_name = isset($wp_query->query_vars['name']) ? $wp_query->query_vars['name'] : (isset($wp_query->query['pagename']) ? $wp_query->query['pagename'] : false);            
            if ($query_page_name != ($optimization->showcase->slug ? $optimization->showcase->slug : $optimization['showcase']['slug'])) return false;
            include_once plugin_dir_path(EVR_HANDLER_FILE) . 'templates/single-review.php';
            exit();
        }



        /**
         * On WooCommerce Thank you Page
         */

        function build_dynamic_message($pre_text = '', $args = [])
        {

            $output = $pre_text;

            if ($args && !empty($args)) {
                foreach ($args as $arg => $value) {
                    $output = preg_replace("/\{$arg\}/i", $value, $output);;
                }
            }

            return $output;
        }



        /**
         * Email message
         */
 
        function getEmailAppendMessage()
        {
            $email = get_evr_option('email');
            $recorder_page = get_evr_option('recorder_page');

            $url = get_permalink($recorder_page) . '?tag=orders&source=email';

            $message = $this->build_dynamic_message("<div style=\"padding-top:15px; font-family:\"Helvetica Neue\",Helvetica,Roboto,Arial,sans-serif;\"><div style=\"text-align: center;\">{$email->message}</div></div>", [
                'button' => "<div style=\"text-align:center; padding-top: 8px; margin-top: 5px; \">
            <a href=\"{$url}\" target=\"_blank\" style=\"background: {$email->button->bg}; color: {$email->button->color}; font-size: {$email->button->size}px; padding: 10px 12px; border-radius: 5px; text-decoration: none;\">
                {$email->button->text}
            </a>
        </div>"
            ]);

            return apply_filters('evr_thankyou_email_html', $message);
        }



        /**
         * WooCommerce Email footer
         */

        function evr_woocommerce_email_footer($email)
        {
            if ($email->id != 'customer_completed_order') return false;
            $woocommerce_option = get_evr_option('woocommerce');
            if (!$woocommerce_option->order_complete->email) return false;

            echo wp_kses_post($this->getEmailAppendMessage()); 
        }



        /**
         * Easy Digital Downloads Button after purchasing
         */

        function evr_edd_add_review_button()
        {
            $edd_option = get_evr_option('edd');

            if (!$edd_option->order_complete->button) return false;
            $button = get_evr_option('button');
            echo wp_kses_post(do_shortcode('[evr-button tag="edd-review"]'));
        }



        /**
         * Easy Digital Downloads Email Footer
         */
        function evr_edd_email_footer()
        {
            $edd_option = get_evr_option('edd');
            if (!$edd_option->order_complete->email) return false;

            echo wp_kses_post($this->getEmailAppendMessage());
        }




        /**
         * Single Video Page Styles
         */
        function add_styles_to_single_video_page()
        {
            if (!is_admin()) {
                wp_enqueue_style('evr_single_style', plugin_dir_url(EVR_HANDLER_FILE) . "public/css/frontend.css", [], null, false);
            }
        }




        /**
         * Single Video Page Scripts
         */

        function add_scripts_to_single_video_page()
        {
            if (!is_admin()) {
                wp_enqueue_script('jquery');
                wp_enqueue_script('evr_single_sc ript', plugin_dir_url(EVR_HANDLER_FILE) . "public/js/frontend.js", [], null, false);
            }
        }


        /**
         * Custom Plugin Action Link
         */
        function evr_plugin_action_links($links)
        { 
            /**
            * Custom links
            */
            $reviews_link = '<a href="' . esc_url(add_query_arg('page', 'evr-admin/#reviews', get_admin_url() . 'admin.php')) . '">' . __('Reviews', 'easy-video-reviews') . '</a>';
            $setting_link = '<a href="' . esc_url(add_query_arg('page', 'evr-admin/#settings', get_admin_url() . 'admin.php')) . '">' . __('Settings', 'easy-video-reviews') . '</a>';
            $pro_link = '<a class="text-red-400 hover:text-red-500 transition duration-150" target="_blank" href="' . esc_url('https://go.wppool.dev/adJ') . '">' . __('Get Pro', 'easy-video-reviews') . '</a>';
 
            $isPro =  get_option('evr_isPro');
            $isLoggedIn =  get_option('evr_token');

            if($isLoggedIn) {
                array_unshift($links, wp_kses_post($setting_link));
                array_unshift($links, wp_kses_post($reviews_link));
            } 
            if($isPro != 'true'){
                array_push($links, wp_kses_post($pro_link)); 
            }

            return $links;
        }



        /**
         * Elementor before scripts add custom icon class 
         */
        function evr_elementor_before_enqueue_scripts()
        {
            echo '<style>';
            echo '
.evr-logo-icon {
  width: 25px;
height: 20px;
display: inline-block;
margin: auto;
  background-image: url(\'' . plugin_dir_url(EVR_HANDLER_FILE) . 'public/images/evr.svg\') !important;
  background-size: 100%;
}';
            echo '</style>';
        }
    }
}
