<?php

namespace EasyVideoReviews;

if (!defined('ABSPATH')) exit; // Exit if accessed directly


/**
 * Elementor Widget Class for Showcase
 */

if (!class_exists('\EasyVideoReviews\EVR_ElementorShowcase')) {

    class EVR_ElementorShowcase extends \Elementor\Widget_Base
    {

        public function get_name()
        {
            return 'evr-showcase';
        }

        public function get_title()
        {
            return __('Easy Video Reviews Showcase', 'easy-video-reviews');
        }

        public function get_icon()
        {
            return 'evr-logo-icon';
        }

        public function get_categories()
        {
            return ['general'];
        }

        protected function _register_controls()
        {

            $this->start_controls_section(
                'section_content',
                [
                    'label' => __('Settings', 'easy-video-reviews'),
                ]
            );

            $this->add_control(
                'view',
                [
                    'label' => __('Testimonial View', 'easy-video-reviews'),
                    'type' => 'choose',
                    'options' => [
                        'grid' => [
                            'title' => __('Grid View', 'easy-video-reviews'),
                            'icon' => 'fa fa-th',
                        ],
                        'slider' => [
                            'title' => __('Slider View', 'easy-video-reviews'),
                            'icon' => 'fa fa-film',
                        ],
                    ],
                    'default' => 'grid',
                ]
            );

            $this->add_control(
                'limit',
                [
                    'label' => __('Video Limit', 'easy-video-reviews'),
                    'type' => 'number',
                    'default' => 10,
                ]
            );
            $this->add_responsive_control(
                'column',
                [
                    'label' => __('Columns', 'easy-video-reviews'),
                    'type' => 'number',
                    'min' => 1,
                    'max' => 9,
                    'desktop_default' => 4,
                    'tablet_default' => 2,
                    'mobile_default' => 1,
                    'condition' => ['view' => 'grid']
                ]
            );


            $this->add_control(
                'order',
                [
                    'label' => __('Order', 'easy-video-reviews'),
                    'type' => 'select',
                    'options' => [
                        'asc' => __('ASC', 'easy-video-reviews'),
                        'desc' => __('DESC', 'easy-video-reviews'),
                    ],
                    'default' => 'desc',
                ]
            );
            $this->add_control(
                'tag',
                [
                    'label' => __('Recording Tag', 'easy-video-reviews'),
                    'type' => 'text',
                    'default' => 'general'
                ]
            );


            $this->end_controls_section();

            $this->start_controls_section(
                'style_section',
                [
                    'label' => __('Recorder Button', 'easy-video-reviews'),
                ]
            );


            $this->add_control(
                'button',
                [
                    'label' => __('Add Recorder Button', 'easy-video-reviews'),
                    'type' => 'switcher',
                    'default' => 'desc',
                ]
            );

            $this->add_control(
                'button_position',
                [
                    'label' => __('Position', 'easy-video-reviews'),
                    'type' => 'select',
                    'options' => [
                        'top' => __('Top', 'easy-video-reviews'),
                        'bottom' => __('Bottom', 'easy-video-reviews'),
                    ],
                    'default' => 'top',
                    'condition' => ['button' => 'yes']
                ]
            );

            $this->add_control(
                'button_label',
                [
                    'label' => __('Button Label', 'easy-video-reviews'),
                    'type' => 'text',
                    'default' => 'Leave Your Speach!',
                    'condition' => ['button' => 'yes']
                ]
            );

            $this->add_control(
                'button_bg_color',
                [
                    'label' => __('Button Background Color', 'easy-video-reviews'),
                    'type' => 'color',
                    'default' => 'blue',
                ]
            );
            $this->add_control(
                'button_text_color',
                [
                    'label' => __('Button Text Color', 'easy-video-reviews'),
                    'type' => 'color',
                    'default' => 'white',
                ]
            );


            $this->add_control(
                'button_size',
                [
                    'label' => __('Button Size', 'easy-video-reviews'),
                    'type' => 'select',
                    'options' => [
                        '4xl' => __('Extra Extra Large', 'easy-video-reviews'),
                        '2xl' => __('Extra Large', 'easy-video-reviews'),
                        'md' => __('Medium', 'easy-video-reviews'),
                        'lg' => __('Normal', 'easy-video-reviews'),
                        'sm' => __('Small', 'easy-video-reviews'),
                        'xs' => __('Extra Small', 'easy-video-reviews'),
                    ],
                    'default' => 'md',
                    'condition' => ['button' => 'yes']
                ]
            );

            $this->add_control(
                'button_alignment',
                [
                    'label' => __('Button Alignment', 'easy-video-reviews'),
                    'type' => 'choose',
                    'options' => [
                        'left' => [
                            'title' => __('Left', 'easy-video-reviews'),
                            'icon' => 'fa fa-align-left',
                        ],
                        'center' => [
                            'title' => __('Center', 'easy-video-reviews'),
                            'icon' => 'fa fa-align-center',
                        ],
                        'right' => [
                            'title' => __('Right', 'easy-video-reviews'),
                            'icon' => 'fa fa-align-right',
                        ],
                    ],
                    'default' => 'center',
                    'condition' => ['button' => 'yes']
                ]
            );

            $this->end_controls_section();
        }


        protected function render()
        {
            $settings = $this->get_settings_for_display();

            $showcase = '[evr-videos view=' . esc_attr($settings['view']) . ' limit=' . esc_attr($settings['limit']) . ' order=' . esc_attr($settings['order']) . ' tag=' .esc_attr($settings['tag']) . '][/evr-videos]';
                    
            $button = '[evr-button align=' . esc_attr($settings['button_alignment']) . ' size=' . esc_attr($settings['button_size']) . ' color=' . esc_html($settings['button_text_color']) . ' bg=' . esc_html($settings['button_bg_color']) . ' tag=' . esc_attr($settings['tag']) . ']' . esc_html($settings['button_label']) . '[/evr-button]';

            $output = $showcase;
            if ($settings['button'] == 'yes') {
                if ($settings['button_position'] == 'top') {
                    $output = $button . $showcase;
                } else {
                    $output = $showcase . $button;
                }
            }

           echo (is_admin()) ? wp_kses_post(do_shortcode( $output) ) : wp_kses_post($output);
        }
    }
}
